@@ -10,11 +10,11 @@
  */
 
 #include "tkInt.h"
-#include "tkPort.h"
 
-#if !(defined(__WIN32__) && defined(MAC_OSX_TK))
+#if !(defined(__WIN32__) || defined(MAC_OSX_TK))
 /* UNIX */
 #define UNIX_TK
+#include "tkUnixInt.h"
 #endif
 
 #ifdef __WIN32__
@@ -22,14 +22,12 @@
 #endif
 
 #if defined(MAC_OSX_TK)
-/* set this locally .. we could have used _TKMACINT */
+/* we could have used _TKMACINT */
 #include "tkMacOSXInt.h"
 #endif
 
-#include "tkDecls.h"
+/* TODO: These ought to come in some other way */
 #include "tkPlatDecls.h"
-#include "tkIntDecls.h"
-#include "tkIntPlatDecls.h"
 #include "tkIntXlibDecls.h"
 
 #define TkUnusedStubEntry NULL
@@ -88,6 +86,7 @@ XVisualIDFromVisual(Visual *visual)
 #   define TkUnixSetMenubar 0
 #   define TkWmCleanup (void (*) (TkDisplay *)) doNothing
 #   define TkSendCleanup (void (*) (TkDisplay *)) doNothing
+#   define TkpTestsendCmd 0
 #   define XFlush (int (*) (Display *)) doNothing
 #   define XGrabServer (int (*) (Display *)) doNothing
 #   define XUngrabServer (int (*) (Display *)) doNothing
@@ -249,14 +248,14 @@ void TkSubtractRegion (TkRegion a, TkRegion b, TkRegion c)
 #	undef TkUnionRectWithRegion
 #	undef TkSubtractRegion
 
-#	define TkClipBox (void (*) _ANSI_ARGS_((TkRegion, XRectangle *))) XClipBox
+#	define TkClipBox (void (*) (TkRegion, XRectangle *)) XClipBox
 #	define TkCreateRegion (TkRegion (*) ()) XCreateRegion
-#	define TkDestroyRegion (void (*) _ANSI_ARGS_((TkRegion))) XDestroyRegion
-#	define TkIntersectRegion (void (*) _ANSI_ARGS_((TkRegion, TkRegion, TkRegion))) XIntersectRegion
-#	define TkRectInRegion (int (*) _ANSI_ARGS_((TkRegion, int, int, unsigned int, unsigned int))) XRectInRegion
-#	define TkSetRegion (void (*) _ANSI_ARGS_((Display *, GC, TkRegion))) XSetRegion
-#	define TkUnionRectWithRegion (void (*) _ANSI_ARGS_((XRectangle *, TkRegion, TkRegion))) XUnionRectWithRegion
-#	define TkSubtractRegion (void (*) _ANSI_ARGS_((TkRegion, TkRegion, TkRegion))) XSubtractRegion
+#	define TkDestroyRegion (void (*) (TkRegion)) XDestroyRegion
+#	define TkIntersectRegion (void (*) (TkRegion, TkRegion, TkRegion)) XIntersectRegion
+#	define TkRectInRegion (int (*) (TkRegion, int, int, unsigned int, unsigned int)) XRectInRegion
+#	define TkSetRegion (void (*) (Display *, GC, TkRegion)) XSetRegion
+#	define TkUnionRectWithRegion (void (*) (XRectangle *, TkRegion, TkRegion)) XUnionRectWithRegion
+#	define TkSubtractRegion (void (*) (TkRegion, TkRegion, TkRegion)) XSubtractRegion
 #   endif
 #endif /* !__WIN32__ */
 
@@ -448,14 +447,14 @@ TkIntStubs tkIntStubs = {
     TkStylePkgFree, /* 147 */
     TkToplevelWindowForCommand, /* 148 */
     TkGetOptionSpec, /* 149 */
-    NULL, /* 150 */
-    NULL, /* 151 */
+    TkMakeRawCurve, /* 150 */
+    TkMakeRawCurvePostscript, /* 151 */
     TkpDrawFrame, /* 152 */
-    NULL, /* 153 */
-    NULL, /* 154 */
+    TkCreateThreadExitHandler, /* 153 */
+    TkDeleteThreadExitHandler, /* 154 */
     NULL, /* 155 */
-    NULL, /* 156 */
-    NULL, /* 157 */
+    TkpTestembedCmd, /* 156 */
+    TkpTesttextCmd, /* 157 */
     NULL, /* 158 */
     NULL, /* 159 */
     NULL, /* 160 */
@@ -467,18 +466,18 @@ TkIntStubs tkIntStubs = {
     NULL, /* 166 */
     NULL, /* 167 */
     NULL, /* 168 */
-    NULL, /* 169 */
-    NULL, /* 170 */
-    NULL, /* 171 */
-    NULL, /* 172 */
-    NULL, /* 173 */
-    NULL, /* 174 */
-    NULL, /* 175 */
-    NULL, /* 176 */
-    NULL, /* 177 */
-    NULL, /* 178 */
-    NULL, /* 179 */
-    NULL, /* 180 */
+    TkStateParseProc, /* 169 */
+    TkStatePrintProc, /* 170 */
+    TkCanvasDashParseProc, /* 171 */
+    TkCanvasDashPrintProc, /* 172 */
+    TkOffsetParseProc, /* 173 */
+    TkOffsetPrintProc, /* 174 */
+    TkPixelParseProc, /* 175 */
+    TkPixelPrintProc, /* 176 */
+    TkOrientParseProc, /* 177 */
+    TkOrientPrintProc, /* 178 */
+    TkSmoothParseProc, /* 179 */
+    TkSmoothPrintProc, /* 180 */
     NULL, /* 181 */
     NULL, /* 182 */
     NULL, /* 183 */
@@ -534,7 +533,7 @@ TkIntPlatStubs tkIntPlatStubs = {
     TkUnixSetMenubar, /* 42 */
     TkWmCleanup, /* 43 */
     TkSendCleanup, /* 44 */
-    TkUnusedStubEntry, /* 45 */
+    TkpTestsendCmd, /* 45 */
 #endif /* WIN */
 #ifdef MAC_OSX_TK /* AQUA */
     TkGenerateActivateEvents, /* 0 */
@@ -591,7 +590,7 @@ TkIntPlatStubs tkIntPlatStubs = {
     TkGenWMDestroyEvent, /* 51 */
     NULL, /* 52 */
     TkpGetMS, /* 53 */
-    TkUnusedStubEntry, /* 54 */
+    TkMacOSXDrawable, /* 54 */
 #endif /* AQUA */
 #if !(defined(__WIN32__) || defined(__CYGWIN__) || defined(MAC_OSX_TK)) /* X11 */
     TkCreateXEventSource, /* 0 */
@@ -607,7 +606,7 @@ TkIntPlatStubs tkIntPlatStubs = {
     TkSendCleanup, /* 10 */
     TkFreeXId, /* 11 */
     TkpWmSetState, /* 12 */
-    TkUnusedStubEntry, /* 13 */
+    TkpTestsendCmd, /* 13 */
 #endif /* X11 */
 };
 
@@ -1011,9 +1010,9 @@ TkStubs tkStubs = {
     Tk_PhotoPutZoomedBlock_NoComposite, /* 145 */
     Tk_PhotoGetImage, /* 146 */
     Tk_PhotoBlank, /* 147 */
-    Tk_PhotoExpand, /* 148 */
+    Tk_PhotoExpand_Panic, /* 148 */
     Tk_PhotoGetSize, /* 149 */
-    Tk_PhotoSetSize, /* 150 */
+    Tk_PhotoSetSize_Panic, /* 150 */
     Tk_PointToChar, /* 151 */
     Tk_PostscriptFontName, /* 152 */
     Tk_PreserveColormap, /* 153 */
@@ -1109,8 +1108,8 @@ TkStubs tkStubs = {
     Tk_SetInternalBorderEx, /* 243 */
     Tk_SetMinimumRequestSize, /* 244 */
     Tk_SetCaretPos, /* 245 */
-    Tk_PhotoPutBlock, /* 246 */
-    Tk_PhotoPutZoomedBlock, /* 247 */
+    Tk_PhotoPutBlock_Panic, /* 246 */
+    Tk_PhotoPutZoomedBlock_Panic, /* 247 */
     Tk_CollapseMotionEvents, /* 248 */
     Tk_RegisterStyleEngine, /* 249 */
     Tk_GetStyleEngine, /* 250 */
@@ -1128,15 +1127,15 @@ TkStubs tkStubs = {
     Tk_GetElementBox, /* 262 */
     Tk_GetElementBorderWidth, /* 263 */
     Tk_DrawElement, /* 264 */
-    NULL, /* 265 */
-    NULL, /* 266 */
-    NULL, /* 267 */
-    NULL, /* 268 */
-    NULL, /* 269 */
-    NULL, /* 270 */
-    NULL, /* 271 */
-    NULL, /* 272 */
-    NULL, /* 273 */
+    Tk_PhotoExpand, /* 265 */
+    Tk_PhotoPutBlock, /* 266 */
+    Tk_PhotoPutZoomedBlock, /* 267 */
+    Tk_PhotoSetSize, /* 268 */
+    Tk_GetUserInactiveTime, /* 269 */
+    Tk_ResetUserInactiveTime, /* 270 */
+    Tk_Interp, /* 271 */
+    Tk_CreateOldImageType, /* 272 */
+    Tk_CreateOldPhotoImageFormat, /* 273 */
     NULL, /* 274 */
     TkUnusedStubEntry, /* 275 */
 };
@@ -1144,5 +1143,4 @@ TkStubs tkStubs = {
 /* !END!: Do not edit above this line. */
 
 #undef UNIX_TK
-#undef MAC_TK
 #undef MAC_OSX_TK
