@@ -10,8 +10,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tkTextTag.c,v 1.27 2007/12/13 15:24:17 dgp Exp $
  */
 
 #include "default.h"
@@ -25,7 +23,7 @@
  * a whole is not.
  */
 
-static char *wrapStrings[] = {
+static const char *wrapStrings[] = {
     "char", "none", "word", "", NULL
 };
 
@@ -36,7 +34,7 @@ static char *wrapStrings[] = {
  * widget as a whole is not.
  */
 
-static char *tabStyleStrings[] = {
+static const char *tabStyleStrings[] = {
     "tabular", "wordprocessor", "", NULL
 };
 
@@ -459,6 +457,11 @@ TkTextTagCmd(
 			&tagPtr->elide) != TCL_OK) {
 		    return TCL_ERROR;
 		}
+	        /* Indices are potentially obsolete after changing -elide,
+	         * especially those computed with "display" or "any"
+                 * submodifier, therefore increase the epoch.
+                 */
+	        textPtr->sharedTextPtr->stateEpoch++;
 	    }
 
 	    /*
