@@ -1,27 +1,26 @@
-/* 
+/*
  * tkMacOSXTest.c --
  *
  *	Contains commands for platform specific tests for
  *	the Macintosh platform.
  *
  * Copyright (c) 1996 Sun Microsystems, Inc.
- * Copyright 2001, Apple Computer, Inc.
+ * Copyright 2001-2009, Apple Inc.
+ * Copyright (c) 2005-2009 Daniel A. Steffen <das@users.sourceforge.net>
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tkMacOSXTest.c,v 1.2.2.2 2005/11/27 02:36:46 das Exp $
  */
 
-#include "tkMacOSXInt.h"
+#include "tkMacOSXPrivate.h"
 
 /*
  * Forward declarations of procedures defined later in this file:
  */
 
-int			TkplatformtestInit _ANSI_ARGS_((Tcl_Interp *interp));
-static int		DebuggerCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
+static int		DebuggerCmd (ClientData dummy, Tcl_Interp *interp,
+			    int argc, const char **argv);
+MODULE_SCOPE int	TkplatformtestInit(Tcl_Interp *interp);
 
 /*
  *----------------------------------------------------------------------
@@ -47,9 +46,9 @@ TkplatformtestInit(
     /*
      * Add commands for platform specific tests on MacOS here.
      */
-    
+
     Tcl_CreateCommand(interp, "debugger", DebuggerCmd,
-            (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
+	    (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
 
     return TCL_OK;
 }
@@ -75,8 +74,17 @@ DebuggerCmd(
     ClientData clientData,		/* Not used. */
     Tcl_Interp *interp,			/* Not used. */
     int argc,				/* Not used. */
-    CONST char **argv)			/* Not used. */
+    const char **argv)			/* Not used. */
 {
     Debugger();
     return TCL_OK;
 }
+
+/*
+ * Local Variables:
+ * mode: objc
+ * c-basic-offset: 4
+ * fill-column: 79
+ * coding: utf-8
+ * End:
+ */
