@@ -5,8 +5,8 @@
  *
  * Copyright (c) 1995 Sun Microsystems, Inc.
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ * See the file "license.terms" for information on usage and redistribution of
+ * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
 #include "tkWinInt.h"
@@ -66,10 +66,10 @@ BOOL APIENTRY		DllMain(HINSTANCE hInst, DWORD reason,
  */
 
 BOOL APIENTRY
-DllEntryPoint(hInst, reason, reserved)
-    HINSTANCE hInst;		/* Library instance handle. */
-    DWORD reason;		/* Reason this function is being called. */
-    LPVOID reserved;		/* Not used. */
+DllEntryPoint(
+    HINSTANCE hInst,		/* Library instance handle. */
+    DWORD reason,		/* Reason this function is being called. */
+    LPVOID reserved)		/* Not used. */
 {
     return DllMain(hInst, reason, reserved);
 }
@@ -95,11 +95,11 @@ DllEntryPoint(hInst, reason, reserved)
  *----------------------------------------------------------------------
  */
 
-BOOL WINAPI
-DllMain(hInstance, reason, reserved)
-    HINSTANCE hInstance;
-    DWORD reason;
-    LPVOID reserved;
+BOOL APIENTRY
+DllMain(
+    HINSTANCE hInstance,
+    DWORD reason,
+    LPVOID reserved)
 {
 #ifdef HAVE_NO_SEH
     EXCEPTION_REGISTRATION registration;
@@ -133,11 +133,11 @@ DllMain(hInstance, reason, reserved)
 
 	    "leaq	%[registration], %%rdx"		"\n\t"
 	    "movq	%%gs:0,		%%rax"		"\n\t"
-	    "movq	%%rax,		0x0(%%edx)"	"\n\t" /* link */
+	    "movq	%%rax,		0x0(%%rdx)"	"\n\t" /* link */
 	    "leaq	1f,		%%rax"		"\n\t"
 	    "movq	%%rax,		0x8(%%rdx)"	"\n\t" /* handler */
-	    "movq	%%rbp,		0x10(%%rdx)"	"\n\t" /* ebp */
-	    "movq	%%rsp,		0x18(%%rdx)"	"\n\t" /* esp */
+	    "movq	%%rbp,		0x10(%%rdx)"	"\n\t" /* rbp */
+	    "movq	%%rsp,		0x18(%%rdx)"	"\n\t" /* rsp */
 	    "movl	%[error],	0x20(%%rdx)"	"\n\t" /* status */
 
 	    /*
@@ -150,7 +150,7 @@ DllMain(hInstance, reason, reserved)
 	     * Call TkFinalize
 	     */
 
-	    "movq	$0x0,		%%rcx"		"\n\t"
+	    "movq	$0x0,		0x0(%%esp)"		"\n\t"
 	    "call	TkFinalize"			"\n\t"
 
 	    /*
