@@ -8,8 +8,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tkWinButton.c,v 1.34.2.2 2009/11/02 04:52:40 mistachkin Exp $
  */
 
 #define OEMRESOURCE
@@ -71,7 +69,6 @@ typedef struct ThreadSpecificData {
     LPSTR boxesBits;		/* Pointer to bitmap data. */
     DWORD boxHeight;		/* Height of each sub-image. */
     DWORD boxWidth;		/* Width of each sub-image. */
-    char defWidth[TCL_INTEGER_SPACE];
 } ThreadSpecificData;
 static Tcl_ThreadDataKey dataKey;
 
@@ -93,6 +90,7 @@ Tk_ClassProcs tkpButtonProcs = {
     sizeof(Tk_ClassProcs),	/* size */
     TkButtonWorldChanged,	/* worldChangedProc */
     CreateProc,			/* createProc */
+    NULL					/* modalProc */
 };
 
 
@@ -164,40 +162,6 @@ InitBoxes(void)
     }
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * ButtonDefaultsExitHandler --
- *
- *	Frees the defaults for the buttons.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-static void
-ButtonDefaultsExitHandler(
-    ClientData clientData)	/* Points to an array of option specs,
-				 * terminated by one with type
-				 * TK_OPTION_END. */
-{
-    Tk_OptionSpec *specPtr = (Tk_OptionSpec *)clientData;
-
-    for ( ; specPtr->type != TK_OPTION_END; specPtr++) {
-	if (specPtr->internalOffset == Tk_Offset(TkButton, borderWidth)) {
-	    if (specPtr->defValue != NULL) {
-		ckfree((char *) specPtr->defValue);
-		specPtr->defValue = NULL;
-	    }
-	}
-    }
-}
-
 /*
  *----------------------------------------------------------------------
  *
@@ -217,31 +181,12 @@ ButtonDefaultsExitHandler(
  */
 
 void
-TkpButtonSetDefaults(
-    Tk_OptionSpec *specPtr)	/* Points to an array of option specs,
-				 * terminated by one with type
-				 * TK_OPTION_END. */
+TkpButtonSetDefaults()
 {
-    int width;
-    Tk_OptionSpec *savedSpecPtr = specPtr;
-    ThreadSpecificData *tsdPtr = (ThreadSpecificData *)
-	    Tcl_GetThreadData(&dataKey, sizeof(ThreadSpecificData));
-
-    if (tsdPtr->defWidth[0] == 0) {
-	width = GetSystemMetrics(SM_CXEDGE);
-	if (width == 0) {
-	    width = 1;
-	}
-	sprintf(tsdPtr->defWidth, "%d", width);
+    int width = GetSystemMetrics(SM_CXEDGE);
+    if (width > 0) {
+	sprintf(tkDefButtonBorderWidth, "%d", width);
     }
-    for ( ; specPtr->type != TK_OPTION_END; specPtr++) {
-	if (specPtr->internalOffset == Tk_Offset(TkButton, borderWidth)) {
-	    char *defValue = (char *) ckalloc(strlen(tsdPtr->defWidth) + 1);
-	    strcpy(defValue, tsdPtr->defWidth);
-	    specPtr->defValue = defValue;
-	}
-    }
-    TkCreateExitHandler(ButtonDefaultsExitHandler, (ClientData) savedSpecPtr);
 }
 
 /*
