@@ -26,7 +26,6 @@
 #define BLACK		"Black"
 #define WHITE		"White"
 
-#define CTL_FONT	"{MS Sans Serif} 8"
 #define NORMAL_BG	"SystemButtonFace"
 #define NORMAL_FG	"SystemButtonText"
 #define ACTIVE_BG	NORMAL_BG
@@ -62,7 +61,7 @@
 #define DEF_BUTTON_DISABLED_FG_MONO	""
 #define DEF_BUTTON_FG			NORMAL_FG
 #define DEF_CHKRAD_FG			TEXT_FG
-#define DEF_BUTTON_FONT		CTL_FONT
+#define DEF_BUTTON_FONT			"TkDefaultFont"
 #define DEF_BUTTON_HEIGHT		"0"
 #define DEF_BUTTON_HIGHLIGHT_BG_COLOR	DEF_BUTTON_BG_COLOR
 #define DEF_BUTTON_HIGHLIGHT_BG_MONO	DEF_BUTTON_BG_MONO
@@ -91,6 +90,7 @@
 #define DEF_BUTTON_TAKE_FOCUS		(char *) NULL
 #define DEF_BUTTON_TEXT			""
 #define DEF_BUTTON_TEXT_VARIABLE	""
+#define DEF_BUTTON_TRISTATE_VALUE	""
 #define DEF_BUTTON_UNDERLINE		"-1"
 #define DEF_BUTTON_VALUE		""
 #define DEF_BUTTON_WIDTH		"0"
@@ -139,13 +139,13 @@
 
 #define DEF_ENTRY_BG_COLOR		"SystemWindow"
 #define DEF_ENTRY_BG_MONO		WHITE
-#define DEF_ENTRY_BORDER_WIDTH		"2"
+#define DEF_ENTRY_BORDER_WIDTH		"1"
 #define DEF_ENTRY_CURSOR		"xterm"
 #define DEF_ENTRY_DISABLED_BG_COLOR	"SystemButtonFace"
 #define DEF_ENTRY_DISABLED_BG_MONO	WHITE
 #define DEF_ENTRY_DISABLED_FG		DISABLED
 #define DEF_ENTRY_EXPORT_SELECTION	"1"
-#define DEF_ENTRY_FONT			CTL_FONT
+#define DEF_ENTRY_FONT			"TkTextFont"
 #define DEF_ENTRY_FG			TEXT_FG
 #define DEF_ENTRY_HIGHLIGHT_BG		NORMAL_BG
 #define DEF_ENTRY_HIGHLIGHT		HIGHLIGHT
@@ -203,7 +203,7 @@
 #define DEF_LABELFRAME_CLASS		"Labelframe"
 #define DEF_LABELFRAME_RELIEF		"groove"
 #define DEF_LABELFRAME_FG		NORMAL_FG
-#define DEF_LABELFRAME_FONT		CTL_FONT
+#define DEF_LABELFRAME_FONT		"TkDefaultFont"
 #define DEF_LABELFRAME_TEXT		""
 #define DEF_LABELFRAME_LABELANCHOR	"nw"
 
@@ -214,11 +214,11 @@
 #define DEF_LISTBOX_ACTIVE_STYLE	"underline"
 #define DEF_LISTBOX_BG_COLOR		"SystemWindow"
 #define DEF_LISTBOX_BG_MONO		WHITE
-#define DEF_LISTBOX_BORDER_WIDTH	"2"
+#define DEF_LISTBOX_BORDER_WIDTH	"1"
 #define DEF_LISTBOX_CURSOR		""
 #define DEF_LISTBOX_DISABLED_FG		DISABLED
 #define DEF_LISTBOX_EXPORT_SELECTION	"1"
-#define DEF_LISTBOX_FONT		CTL_FONT
+#define DEF_LISTBOX_FONT		"TkDefaultFont"
 #define DEF_LISTBOX_FG			NORMAL_FG
 #define DEF_LISTBOX_HEIGHT		"10"
 #define DEF_LISTBOX_HIGHLIGHT_BG	NORMAL_BG
@@ -282,7 +282,7 @@
 #define DEF_MENU_CURSOR			"arrow"
 #define DEF_MENU_DISABLED_FG_COLOR	DISABLED
 #define DEF_MENU_DISABLED_FG_MONO	""
-#define DEF_MENU_FONT			CTL_FONT
+#define DEF_MENU_FONT			"TkMenuFont"
 #define DEF_MENU_FG			MENU_FG
 #define DEF_MENU_POST_COMMAND		""
 #define DEF_MENU_RELIEF			"flat"
@@ -306,12 +306,12 @@
 #define DEF_MENUBUTTON_BG_COLOR		NORMAL_BG
 #define DEF_MENUBUTTON_BG_MONO		WHITE
 #define DEF_MENUBUTTON_BITMAP		""
-#define DEF_MENUBUTTON_BORDER_WIDTH	"2"
+#define DEF_MENUBUTTON_BORDER_WIDTH	"1"
 #define DEF_MENUBUTTON_CURSOR		""
 #define DEF_MENUBUTTON_DIRECTION	"below"
 #define DEF_MENUBUTTON_DISABLED_FG_COLOR DISABLED
 #define DEF_MENUBUTTON_DISABLED_FG_MONO	""
-#define DEF_MENUBUTTON_FONT		CTL_FONT
+#define DEF_MENUBUTTON_FONT		"TkDefaultFont"
 #define DEF_MENUBUTTON_FG		NORMAL_FG
 #define DEF_MENUBUTTON_HEIGHT		"0"
 #define DEF_MENUBUTTON_HIGHLIGHT_BG_COLOR DEF_MENUBUTTON_BG_COLOR
@@ -341,10 +341,10 @@
 #define DEF_MESSAGE_ASPECT		"150"
 #define DEF_MESSAGE_BG_COLOR		NORMAL_BG
 #define DEF_MESSAGE_BG_MONO		WHITE
-#define DEF_MESSAGE_BORDER_WIDTH	"2"
+#define DEF_MESSAGE_BORDER_WIDTH	"1"
 #define DEF_MESSAGE_CURSOR		""
 #define DEF_MESSAGE_FG			NORMAL_FG
-#define DEF_MESSAGE_FONT		CTL_FONT
+#define DEF_MESSAGE_FONT		"TkDefaultFont"
 #define DEF_MESSAGE_HIGHLIGHT_BG	NORMAL_BG
 #define DEF_MESSAGE_HIGHLIGHT		HIGHLIGHT
 #define DEF_MESSAGE_HIGHLIGHT_WIDTH	"0"
@@ -363,18 +363,18 @@
 
 #define DEF_PANEDWINDOW_BG_COLOR	NORMAL_BG
 #define DEF_PANEDWINDOW_BG_MONO		WHITE
-#define DEF_PANEDWINDOW_BORDERWIDTH	"2"
+#define DEF_PANEDWINDOW_BORDERWIDTH	"1"
 #define DEF_PANEDWINDOW_CURSOR		""
 #define DEF_PANEDWINDOW_HANDLEPAD	"8"
 #define DEF_PANEDWINDOW_HANDLESIZE	"8"
 #define DEF_PANEDWINDOW_HEIGHT		""
-#define DEF_PANEDWINDOW_OPAQUERESIZE	"0"
+#define DEF_PANEDWINDOW_OPAQUERESIZE	"1"
 #define DEF_PANEDWINDOW_ORIENT		"horizontal"
 #define DEF_PANEDWINDOW_RELIEF		"flat"
 #define DEF_PANEDWINDOW_SASHCURSOR	""
-#define DEF_PANEDWINDOW_SASHPAD		"2"
-#define DEF_PANEDWINDOW_SASHRELIEF	"raised"
-#define DEF_PANEDWINDOW_SASHWIDTH	"2"
+#define DEF_PANEDWINDOW_SASHPAD		"0"
+#define DEF_PANEDWINDOW_SASHRELIEF	"flat"
+#define DEF_PANEDWINDOW_SASHWIDTH	"3"
 #define DEF_PANEDWINDOW_SHOWHANDLE	"0"
 #define DEF_PANEDWINDOW_WIDTH		""
 
@@ -390,6 +390,8 @@
 #define DEF_PANEDWINDOW_PANE_PADY	"0"
 #define DEF_PANEDWINDOW_PANE_STICKY	"nsew"
 #define DEF_PANEDWINDOW_PANE_WIDTH	""
+#define DEF_PANEDWINDOW_PANE_HIDE	"0"
+#define DEF_PANEDWINDOW_PANE_STRETCH	"last"
 
 /*
  * Defaults for scales:
@@ -400,11 +402,11 @@
 #define DEF_SCALE_BG_COLOR		NORMAL_BG
 #define DEF_SCALE_BG_MONO		WHITE
 #define DEF_SCALE_BIG_INCREMENT		"0"
-#define DEF_SCALE_BORDER_WIDTH		"2"
+#define DEF_SCALE_BORDER_WIDTH		"1"
 #define DEF_SCALE_COMMAND		""
 #define DEF_SCALE_CURSOR		""
 #define DEF_SCALE_DIGITS		"0"
-#define DEF_SCALE_FONT			CTL_FONT
+#define DEF_SCALE_FONT			"TkDefaultFont"
 #define DEF_SCALE_FG_COLOR		NORMAL_FG
 #define DEF_SCALE_FG_MONO		BLACK
 #define DEF_SCALE_FROM			"0"
@@ -464,11 +466,12 @@
 #define DEF_TEXT_AUTO_SEPARATORS	"1"
 #define DEF_TEXT_BG_COLOR		"SystemWindow"
 #define DEF_TEXT_BG_MONO		WHITE
-#define DEF_TEXT_BORDER_WIDTH		"2"
+#define DEF_TEXT_BLOCK_CURSOR		"0"
+#define DEF_TEXT_BORDER_WIDTH		"1"
 #define DEF_TEXT_CURSOR			"xterm"
 #define DEF_TEXT_FG			TEXT_FG
 #define DEF_TEXT_EXPORT_SELECTION	"1"
-#define DEF_TEXT_FONT			CTL_FONT
+#define DEF_TEXT_FONT			"TkFixedFont"
 #define DEF_TEXT_HEIGHT			"24"
 #define DEF_TEXT_HIGHLIGHT_BG		NORMAL_BG
 #define DEF_TEXT_HIGHLIGHT		HIGHLIGHT
@@ -483,6 +486,7 @@
 #define DEF_TEXT_PADX			"1"
 #define DEF_TEXT_PADY			"1"
 #define DEF_TEXT_RELIEF			"sunken"
+#define DEF_TEXT_INACTIVE_SELECT_COLOR	NULL
 #define DEF_TEXT_SELECT_COLOR		SELECT_BG
 #define DEF_TEXT_SELECT_MONO		BLACK
 #define DEF_TEXT_SELECT_BD_COLOR	"0"
@@ -496,6 +500,7 @@
 #define DEF_TEXT_SPACING3		"0"
 #define DEF_TEXT_STATE			"normal"
 #define DEF_TEXT_TABS			""
+#define DEF_TEXT_TABSTYLE		"tabular"
 #define DEF_TEXT_TAKE_FOCUS		(char *) NULL
 #define DEF_TEXT_UNDO    		"0"
 #define DEF_TEXT_WIDTH			"80"
@@ -507,7 +512,7 @@
  * Defaults for canvas text:
  */
 
-#define DEF_CANVTEXT_FONT		CTL_FONT
+#define DEF_CANVTEXT_FONT		"TkDefaultFont"
 
 /*
  * Defaults for toplevels (most of the defaults for frames also apply
