@@ -63,8 +63,8 @@
 
 
 #ifndef __GNUC__
-#    define strncasecmp strnicmp
-#    define strcasecmp stricmp
+#    define strncasecmp _strnicmp
+#    define strcasecmp _stricmp
 #endif
 
 #define NBBY 8
@@ -97,8 +97,6 @@
 
 #define TkFreeWindowId(dispPtr,w)
 #define TkInitXId(dispPtr)
-#define TkpCmapStressed(tkwin,colormap) (0)
-#define TkpSync(display)
 
 /*
  * The following Tk functions are implemented as macros under Windows.
@@ -116,8 +114,4 @@
 #define TkpCreateNativeBitmap(display, source) None
 #define TkpGetNativeAppBitmap(display, name, w, h) None
 
-#ifndef _TCLINT
-#include <tclInt.h>
-#endif
-
 #endif /* _WINPORT */
