@@ -8,8 +8,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tkWinWindow.c,v 1.15.4.1 2008/07/26 11:49:30 patthoyts Exp $
  */
 
 #include "tkWinInt.h"
@@ -211,7 +209,7 @@ TkpScanWindowId(
     Window *idPtr)		/* Place to store converted result. */
 {
     Tk_Window tkwin;
-    Window number, *numberPtr = &number;
+    void *number, *numberPtr = &number;
 
     /*
      * We want sscanf for the 64-bit check, but if that doesn't work, then
@@ -299,7 +297,7 @@ TkpMakeWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XDestroyWindow(
     Display *display,
     Window w)
@@ -335,6 +333,7 @@ XDestroyWindow(
     if (hwnd != NULL && !(winPtr->flags & TK_DONT_DESTROY_WINDOW)) {
 	DestroyWindow(hwnd);
     }
+    return Success;
 }
 
 /*
@@ -353,7 +352,7 @@ XDestroyWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XMapWindow(
     Display *display,
     Window w)
@@ -377,7 +376,7 @@ XMapWindow(
 	for (parentPtr = winPtr->parentPtr; ;
 		parentPtr = parentPtr->parentPtr) {
 	    if ((parentPtr == NULL) || !(parentPtr->flags & TK_MAPPED)) {
-		return;
+		return Success;
 	    }
 	    if (parentPtr->flags & TK_TOP_HIERARCHY) {
 		break;
@@ -406,6 +405,7 @@ XMapWindow(
     event.xvisibility.window = winPtr->window;
     event.xvisibility.state = VisibilityUnobscured;
     NotifyVisibility(&event, winPtr);
+    return Success;
 }
 
 /*
@@ -461,7 +461,7 @@ NotifyVisibility(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XUnmapWindow(
     Display *display,
     Window w)
@@ -489,6 +489,7 @@ XUnmapWindow(
 	event.xunmap.from_configure = False;
 	Tk_HandleEvent(&event);
     }
+    return Success;
 }
 
 /*
@@ -507,7 +508,7 @@ XUnmapWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XMoveResizeWindow(
     Display *display,
     Window w,
@@ -516,6 +517,7 @@ XMoveResizeWindow(
 {
     display->request++;
     MoveWindow(Tk_GetHWND(w), x, y, (int) width, (int) height, TRUE);
+    return Success;
 }
 
 /*
@@ -534,7 +536,7 @@ XMoveResizeWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XMoveWindow(
     Display *display,
     Window w,
@@ -546,6 +548,7 @@ XMoveWindow(
 
     MoveWindow(Tk_GetHWND(w), x, y, winPtr->changes.width,
 	    winPtr->changes.height, TRUE);
+    return Success;
 }
 
 /*
@@ -564,7 +567,7 @@ XMoveWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XResizeWindow(
     Display *display,
     Window w,
@@ -576,6 +579,7 @@ XResizeWindow(
 
     MoveWindow(Tk_GetHWND(w), winPtr->changes.x, winPtr->changes.y, (int)width,
 	    (int)height, TRUE);
+    return Success;
 }
 
 /*
@@ -594,7 +598,7 @@ XResizeWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XRaiseWindow(
     Display *display,
     Window w)
@@ -603,6 +607,7 @@ XRaiseWindow(
 
     display->request++;
     SetWindowPos(window, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+    return Success;
 }
 
 /*
@@ -624,7 +629,7 @@ XRaiseWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XConfigureWindow(
     Display *display,
     Window w,
@@ -659,6 +664,7 @@ XConfigureWindow(
 	}
 	TkWinSetWindowPos(hwnd, sibling, values->stack_mode);
     }
+    return Success;
 }
 
 /*
@@ -677,7 +683,7 @@ XConfigureWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XClearWindow(
     Display *display,
     Window w)
@@ -705,6 +711,7 @@ XClearWindow(
     DeleteObject(brush);
     SelectPalette(dc, oldPalette, TRUE);
     ReleaseDC(hwnd, dc);
+    return Success;
 }
 
 /*
@@ -725,7 +732,7 @@ XClearWindow(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XChangeWindowAttributes(
     Display *display,
     Window w,
@@ -735,6 +742,7 @@ XChangeWindowAttributes(
     if (valueMask & CWCursor) {
 	XDefineCursor(display, w, attributes->cursor);
     }
+    return Success;
 }
 
 /*
