@@ -5,7 +5,8 @@
  *	contexts.
  *
  * Copyright (c) 1995-1996 Sun Microsystems, Inc.
- * Copyright (c) 2002-2007 Daniel A. Steffen <das@users.sourceforge.net>
+ * Copyright (c) 2002-2009 Daniel A. Steffen <das@users.sourceforge.net>
+ * Copyright 2008-2009, Apple Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -15,15 +16,20 @@
 
 #if !defined(MAC_OSX_TK)
 #   include <X11/Xlib.h>
-#endif
-#ifdef MAC_OSX_TK
+#   define gcCacheSize 0
+#   define TkpInitGCCache(gc)
+#   define TkpFreeGCCache(gc)
+#   define TkpGetGCCache(gc)
+#else
 #   include <tkMacOSXInt.h>
 #   include <X11/Xlib.h>
 #   include <X11/X.h>
 #   define Cursor XCursor
 #   define Region XRegion
+#   define gcCacheSize sizeof(TkpGCCache)
 #endif
 
+#undef TkSetRegion
 
 /*
  *----------------------------------------------------------------------
@@ -43,7 +49,7 @@
 
 static TkpClipMask *AllocClipMask(GC gc) {
     TkpClipMask *clip_mask = (TkpClipMask*) gc->clip_mask;
-    
+
     if (clip_mask == None) {
 	clip_mask = (TkpClipMask*) ckalloc(sizeof(TkpClipMask));
 	gc->clip_mask = (Pixmap) clip_mask;
@@ -117,7 +123,8 @@ XCreateGC(
 
 #define MAX_DASH_LIST_SIZE 10
 
-    gp = (XGCValues *) ckalloc(sizeof(XGCValues) + MAX_DASH_LIST_SIZE);
+    gp = (XGCValues *) ckalloc(sizeof(XGCValues) + MAX_DASH_LIST_SIZE +
+	    gcCacheSize);
     if (!gp) {
 	return None;
     }
@@ -127,9 +134,9 @@ XCreateGC(
 
     InitField(function,		  GCFunction,		GXcopy);
     InitField(plane_mask,	  GCPlaneMask,		(unsigned long)(~0));
-    InitField(foreground,	  GCForeground,		
+    InitField(foreground,	  GCForeground,
 	    BlackPixelOfScreen(DefaultScreenOfDisplay(display)));
-    InitField(background,	  GCBackground,		
+    InitField(background,	  GCBackground,
 	    WhitePixelOfScreen(DefaultScreenOfDisplay(display)));
     InitField(line_width,	  GCLineWidth,		1);
     InitField(line_style,	  GCLineStyle,		LineSolid);
@@ -154,14 +161,37 @@ XCreateGC(
     gp->clip_mask = None;
     if (mask & GCClipMask) {
 	TkpClipMask *clip_mask = AllocClipMask(gp);
-	
+
 	clip_mask->type = TKP_CLIP_PIXMAP;
 	clip_mask->value.pixmap = values->clip_mask;
     }
+    TkpInitGCCache(gp);
 
     return gp;
 }
 
+#ifdef MAC_OSX_TK
+/*
+ *----------------------------------------------------------------------
+ *
+ * TkpGetGCCache --
+ *
+ * Results:
+ *	Pointer to the TkpGCCache at the end of the GC.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+TkpGCCache*
+TkpGetGCCache(GC gc) {
+    return (gc ? (TkpGCCache*)(((char*) gc) + sizeof(XGCValues) +
+	    MAX_DASH_LIST_SIZE) : NULL);
+}
+#endif
+
 /*
  *----------------------------------------------------------------------
  *
@@ -178,7 +208,7 @@ XCreateGC(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XChangeGC(
     Display *d,
     GC gc,
@@ -216,6 +246,7 @@ XChangeGC(
 	gc->dashes = values->dashes;
 	(&(gc->dashes))[1] = 0;
     }
+    return Success;
 }
 
 /*
@@ -234,14 +265,16 @@ XChangeGC(
  *----------------------------------------------------------------------
  */
 
-void XFreeGC(
+int XFreeGC(
     Display *d,
     GC gc)
 {
     if (gc != None) {
 	FreeClipMask(gc);
+	TkpFreeGCCache(gc);
 	ckfree((char *) gc);
     }
+    return Success;
 }
 
 /*
@@ -261,25 +294,27 @@ void XFreeGC(
  *----------------------------------------------------------------------
  */
 
-void
+int
 XSetForeground(
     Display *display,
     GC gc,
     unsigned long foreground)
 {
     gc->foreground = foreground;
+    return Success;
 }
 
-void
+int
 XSetBackground(
     Display *display,
     GC gc,
     unsigned long background)
 {
     gc->background = background;
+    return Success;
 }
 
-void
+int
 XSetDashes(
     Display *display,
     GC gc,
@@ -301,36 +336,40 @@ XSetDashes(
 	*p++ = *dash_list++;
     }
     *p = 0;
+    return Success;
 }
 
-void
+int
 XSetFunction(
     Display *display,
     GC gc,
     int function)
 {
     gc->function = function;
+    return Success;
 }
 
-void
+int
 XSetFillRule(
     Display *display,
     GC gc,
     int fill_rule)
 {
     gc->fill_rule = fill_rule;
+    return Success;
 }
 
-void
+int
 XSetFillStyle(
     Display *display,
     GC gc,
     int fill_style)
 {
     gc->fill_style = fill_style;
+    return Success;
 }
 
-void
+int
 XSetTSOrigin(
     Display *display,
     GC gc,
@@ -338,36 +377,40 @@ XSetTSOrigin(
 {
     gc->ts_x_origin = x;
     gc->ts_y_origin = y;
+    return Success;
 }
 
-void
+int
 XSetFont(
     Display *display,
     GC gc,
     Font font)
 {
     gc->font = font;
+    return Success;
 }
 
-void
+int
 XSetArcMode(
     Display *display,
     GC gc,
     int arc_mode)
 {
     gc->arc_mode = arc_mode;
+    return Success;
 }
 
-void
+int
 XSetStipple(
     Display *display,
     GC gc,
     Pixmap stipple)
 {
     gc->stipple = stipple;
+    return Success;
 }
 
-void
+int
 XSetLineAttributes(
     Display *display,
     GC gc,
@@ -380,9 +423,10 @@ XSetLineAttributes(
     gc->line_style = line_style;
     gc->cap_style = cap_style;
     gc->join_style = join_style;
+    return Success;
 }
 
-void
+int
 XSetClipOrigin(
     Display *display,
     GC gc,
@@ -391,6 +435,7 @@ XSetClipOrigin(
 {
     gc->clip_x_origin = clip_x_origin;
     gc->clip_y_origin = clip_y_origin;
+    return Success;
 }
 
 /*
@@ -421,7 +466,7 @@ TkSetRegion(
     TkRegion r)
 {
     if (r == None) {
-	FreeClipMask(gc);
+	Tcl_Panic("must not pass None to TkSetRegion for compatibility with X11; use XSetClipMask instead");
     } else {
 	TkpClipMask *clip_mask = AllocClipMask(gc);
 
@@ -433,7 +478,7 @@ TkSetRegion(
     }
 }
 
-void
+int
 XSetClipMask(
     Display *display,
     GC gc,
@@ -447,6 +492,7 @@ XSetClipMask(
 	clip_mask->type = TKP_CLIP_PIXMAP;
 	clip_mask->value.pixmap = pixmap;
     }
+    return Success;
 }
 
 /*
